summaryrefslogtreecommitdiffstats
path: root/src/declarative/fx/qfxpixmapcache.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/declarative/fx/qfxpixmapcache.h')
-rw-r--r--src/declarative/fx/qfxpixmapcache.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/declarative/fx/qfxpixmapcache.h b/src/declarative/fx/qfxpixmapcache.h
index fb5b88a..2a5c4fa 100644
--- a/src/declarative/fx/qfxpixmapcache.h
+++ b/src/declarative/fx/qfxpixmapcache.h
@@ -54,13 +54,13 @@ QT_BEGIN_NAMESPACE
QT_MODULE(Declarative)
class QmlEngine;
class QNetworkReply;
-class Q_DECLARATIVE_EXPORT QFxPixmapCache
+class Q_DECLARATIVE_EXPORT QmlGraphicsPixmapCache
{
public:
static QNetworkReply *get(QmlEngine *, const QUrl& url, QPixmap *pixmap);
static void cancelGet(const QUrl& url, QObject* obj);
- static bool find(const QUrl& url, QPixmap *pixmap); // url must have been passed to QFxPixmapCache::get, and any returned reply finished.
+ static bool find(const QUrl& url, QPixmap *pixmap); // url must have been passed to QmlGraphicsPixmapCache::get, and any returned reply finished.
static int pendingRequests(); // mainly for test verification
};